package com.zemanta.hamaxnewsandroid;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ListView;
import android.widget.SimpleAdapter;

public class ArticleListActivity extends ListActivity {
	
	private static final String TAG = "ArticleListActivity";
	private Context mCtx;
	private ArrayList<HamaxArticle> articles;
	private SimpleAdapter adapter;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mCtx = this;
        
        Intent intent = getIntent();
        Bundle extras = intent.getExtras();
        String entity = extras.getString("entity");
        
        articles = Core.getArticles(entity);
        
        ArrayList<Map<String, String>> list = new ArrayList<Map<String, String>>();
        
        for (HamaxArticle article: articles) {
        	HashMap<String, String> map = new HashMap<String, String>();
        	map.put("title", article.title);
        	map.put("url", article.url);
        	map.put("body", article.body);
        	String brief = article.body;
        	if (brief.length() > 100) {
        		brief = brief.substring(0, 100) + "...";
        	}
        	map.put("brief", brief);
        	list.add(map);
        }
        
        String[] from = {"title", "url", "brief"};
        int[] to = {R.id.title, R.id.url, R.id.brief};
        
        adapter = new SimpleAdapter(this, list, R.layout.article_list, from, to);
        ListView lv = getListView();
        lv.setAdapter(adapter);

        lv.setOnItemClickListener(new OnItemClickListener() {
        	public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        		HashMap<String, String> article = (HashMap<String, String>) adapter.getItem(position);
        		Intent intent = new Intent(mCtx, ArticleViewActivity.class);
        		String article_id = article.get("id");
        		intent.putExtra("id", article_id);
        		String article_title = article.get("title");
        		intent.putExtra("title", article_title);
        		String article_body = article.get("body");
        		intent.putExtra("body", article_body);
        		String article_url = article.get("url");
        		intent.putExtra("url", article_url);
        		startActivity(intent);
        	}
        });
    }
}